@@ -1,6 +1,5 @@
+"""Global test fixture configuration"""
 from random import randint
-from typing import Optional
-from typing import Tuple
 
 import numpy as np
 import pytest
@@ -17,7 +16,7 @@ def recipe_run_id():
 class S122Headers(Spec122Dataset):
     def __init__(
         self,
-        array_shape: Tuple[int, ...],
+        array_shape: tuple[int, ...],
         num_steps: int = 4,
         num_exp_per_step: int = 1,
         num_dsps_repeats: int = 5,
@@ -37,7 +36,7 @@ class S122Headers(Spec122Dataset):
 
 
 def generate_214_l0_fits_frame(
-    s122_header: fits.Header, data: Optional[np.ndarray] = None
+    s122_header: fits.Header, data: np.ndarray | None = None
 ) -> fits.HDUList:
     """Convert S122 header into 214 L0"""
     if data is None:
